@@ -1,6 +1,7 @@
+from .discover import discover
 from .libdoc import libdoc
 from .rebot import rebot
 from .robot import robot
 from .testdoc import testdoc
 
-__all__ = ["robot", "libdoc", "rebot", "testdoc"]
+__all__ = ["robot", "libdoc", "rebot", "testdoc", "discover"]
